//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraOptions](index.md)/[hasMultipleYakuman](has-multiple-yakuman.md)

# hasMultipleYakuman

[common]\
val [hasMultipleYakuman](has-multiple-yakuman.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否有多倍役满（false则大四喜、国士无双十三面、纯正九莲宝灯只记单倍役满）
